@@ -22,41 +22,25 @@
 #include <KCModule>
 #include <QDeclarativeListProperty>
 
-class QDeclarativeView;
+class Widget;
 class QTimer;
 
-namespace KScreen {
-class Config;
-}
-
 class KCMKScreen : public KCModule
 {
     Q_OBJECT
-public:
+
+  public:
     explicit KCMKScreen (QWidget* parent = 0, const QVariantList& args = QVariantList());
     virtual ~KCMKScreen();
 
-public Q_SLOTS:
+  public Q_SLOTS:
     virtual void load();
     virtual void save();
+    virtual void defaults();
 
-    static bool x11EventFilter(void* message, long int* result);
+  private:
+    Widget *mKScreenWidget;
 
-private Q_SLOTS:
-    void identifyOutputs();
-    void clearOutputIdentifiers();
-    void moveMouse(int dX, int dY);
-
-    void outputMousePressed();
-    void outputMouseReleased();
-
-private:
-    KScreen::Config *m_config;
-
-    QDeclarativeView *m_declarativeView;
-
-    QList<QWidget*> m_outputIdentifiers;
-    QTimer *m_outputTimer;
 };
 
 #endif // DisplayConfiguration_H
