@@ -163,6 +163,7 @@ void KScreenDaemon::applyGenericConfig()
 
 void KScreenDaemon::lidClosedChanged(bool lidIsClosed)
 {
+    Q_UNUSED(lidIsClosed);
 //     KDebug::Block genericConfig(" Lid closed");
 //     kDebug() << "Lid is closed:" << lidIsClosed;
 //     //If the laptop is closed, use ideal config WITHOUT saving it
@@ -260,3 +261,5 @@ void KScreenDaemon::disableMonitor(KScreen::Output* output)
     disconnect(output, SIGNAL(posChanged()), this, SLOT(configChanged()));
     disconnect(output, SIGNAL(rotationChanged()), this, SLOT(configChanged()));
 }
+
+#include "daemon.moc"
